import { Box, Container, Divider, FormControl, FormControlLabel, FormGroup, InputLabel, MenuItem, Select, Switch, SxProps, TextField, Theme, Typography, styled } from "@mui/material";
import { SettingsContext } from "../../context/settings.provider";
import { useContext, useEffect, useState } from "react";
import { ClickThroughMode, OverlayBehavior } from "../../../electron-src/@core/domain/settings_preset/settings_preset";


// Settings section component
export default function AppSettingsOthers() {

    const { activeSettingsPreset, updateActivePresetBehavior } = useContext( SettingsContext );    

    const overlayBehavior: OverlayBehavior = activeSettingsPreset?.overlay?.behavior;
    const [ clickThroughMode, setClickThroughMode ] = useState<ClickThroughMode>('auto');

    useEffect( () => {

        if ( !overlayBehavior.click_through_mode )
            return;

        setClickThroughMode( overlayBehavior.click_through_mode );

    }, [ overlayBehavior ] )
    

    return (
        <Box sx={{ flexGrow: 1, margin: 1, }}>

            <Typography gutterBottom variant="h6" component="div" margin={2} ml={0}>
                Overlay Behavior
            </Typography>
            
            <Container sx={{ mt: 2, mb: 2 }}>

                <FormGroup>

                    <FormControlLabel label='Click-through mode' labelPlacement="top"
                        sx={{
                            display: 'flex',
                            alignItems: 'flex-start',
                            ml: 0,
                            mb: 2
                        }}
                        control={
                            <Select size="small"
                                value={ clickThroughMode || 'auto' } 
                                onChange={ ( event ) => {
                                    const { value } = event.target
                                    if (typeof value === 'string') {
                                        setClickThroughMode( value as ClickThroughMode );
                                        updateActivePresetBehavior({
                                            click_through_mode: value as ClickThroughMode
                                        })
                                    }
                                }}
                                sx={{ width: '145px' }}
                            >
                                <MenuItem value='auto'>Auto</MenuItem>
                                <MenuItem value='enabled'>Enabled</MenuItem>
                                <MenuItem value='disabled'>Disabled</MenuItem>
                            </Select>
                        }
                    />

                    
                    <FormControlLabel label='React to clicks with click-through enabled'
                        control={
                            <Switch
                                checked={ Boolean( overlayBehavior?.always_forward_mouse_clicks ) }
                                onChange={ ( event ) => {
                                    updateActivePresetBehavior({
                                        always_forward_mouse_clicks: event.target.checked
                                    });
                                }}
                            /> 
                        }
                    />

                    <FormControlLabel label='Always on top' title="Not available when click-through is disabled"
                        control={
                            <Switch
                                checked={ Boolean( overlayBehavior?.always_on_top ) }
                                onChange={ ( event ) => {
                                    updateActivePresetBehavior({
                                        always_on_top: event.target.checked
                                    });
                                }}
                            /> 
                        }
                    />

                    <FormControlLabel label='Copy text on click'
                        control={
                            <Switch
                                checked={ Boolean( overlayBehavior?.copy_text_on_click ) }
                                onChange={ ( event ) => {
                                    updateActivePresetBehavior({
                                        copy_text_on_click: event.target.checked
                                    });
                                }}
                            /> 
                        }
                    />
                    <FormControlLabel label='Auto-copy text on hover'
                        control={
                            <Switch
                                checked={ Boolean( overlayBehavior?.copy_text_on_hover ) }
                                onChange={ ( event ) => {
                                    updateActivePresetBehavior({
                                        copy_text_on_hover: event.target.checked
                                    });
                                }}
                            /> 
                        }
                    />
                    <FormControlLabel label='Show overlay without stealing focus'
                        control={
                            <Switch
                                checked={ Boolean( overlayBehavior.show_window_without_focus ) }
                                onChange={ ( event ) => {
                                    updateActivePresetBehavior({
                                        show_window_without_focus: event.target.checked
                                    });
                                }}
                            /> 
                        }
                    />
                    <FormControlLabel label='Show Yomichan window on text copy'
                        control={
                            <Switch
                                checked={ Boolean( overlayBehavior?.show_yomichan_window_on_copy ) }
                                onChange={ ( event ) => {
                                    updateActivePresetBehavior({
                                        show_yomichan_window_on_copy: event.target.checked
                                    });
                                }}
                            /> 
                        }
                    />
                </FormGroup>
            
            </Container>
                
        </Box>
    )
}